<template>
  <div class="app-container">
    <el-form
      class="responsive-form"
      :model="queryParams"
      ref="queryRef"
      :inline="true"
      v-show="showSearch"
      label-position="left"
    >
      <el-row :gutter="20">
        <el-col :span="6">
          <el-form-item
            :style="{ width: '100%'  }"
            :label="$t('plan.query.workOrderNo')"
            prop="workOrderNo"
          >
            <el-input
              v-model="queryParams.workOrderNo"
              :placeholder="`${$t('common.common.placeholder')}${$t(
                'plan.query.workOrderNo'
              )}`"
              clearable
              @keyup.enter="handleQuery"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item
            :style="{ width: '100%'  }"
            :label="$t('plan.query.requireTraceID')"
            prop="requireTrackId"
          >
            <el-input
              v-model="queryParams.requireTrackId"
              :placeholder="`${$t('common.common.placeholder')}${$t(
                'plan.query.requireTraceID'
              )}`"
              clearable
              @keyup.enter="handleQuery"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item
            :style="{ width: '100%'  }"
            :label="$t('plan.query.itemNumber')"
            prop="mainPartNumber"
          >
            <el-input
              v-model="queryParams.mainPartNumber"
              :placeholder="`${$t('common.common.placeholder')}${$t(
                'plan.query.itemNumber'
              )}`"
              clearable
              @keyup.enter="handleQuery"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item
            :style="{ width: '100%'  }"
            :label="$t('plan.table.delayRiskIdentification')"
            prop="hasDelayRisk"
          >
            <el-select
              clearable
              v-model="queryParams.hasDelayRisk"
            >
              <el-option
                v-for="item in delayRiskOptions"
                :key="item.value"
                :label="item.label"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="Refresh"
          :disabled="multiple"
          @click="handleBatchUpdatePlanDate"
          v-hasPermi="['ApsPlatOrderPlanManager:requirement:list']"
          >{{ $t("plan.btns.batchUpdateOrderDate") }}</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="Edit"
          :disabled="loadingGenerateList"
          @click="handleGenerateList"
          v-hasPermi="['apsPlatePlan:edit']"
          >{{ $t("plan.btns.generatePlanOrder") }}</el-button
        >
      </el-col>
      <right-toolbar
        v-model:showSearch="showSearch"
        @queryTable="handleQuery"
        @resetTable="resetQuery"
      ></right-toolbar>
    </el-row>
    <HxlhTable
      style="width: 100%"
      :columns="columns"
      :data="orderList"
      :loading="loading"
      :height="height"
      ref="tableRef"
      :page="page"
      @changePageNo="changePageNo"
      @changePageSize="changePageSize"
      @on-checkbox="handleCheckboxChange"
    >
      <template #buttons="{ row }">
        <el-button
          type="primary"
          link
          @click="handleCheckLevels(row)"
          v-hasPermi="['ApsPlatOrderPlanManager:requirement:list']"
          >{{ $t("plan.btns.viewUpperLowerLevels") }}</el-button
        >
        <el-button
          type="primary"
          link
          @click="handleCheckView(row)"
          v-hasPermi="['ApsPlatOrderPlanManager:requirement:list']"
          >{{ $t("plan.btns.viewRequirement") }}({{row.requireNum}})</el-button
        >
      </template>
    </HxlhTable>
    <el-dialog
      :title="$t('plan.title.viewAssociatedRequirements')"
      v-model="openDialog"
      width="85%"
      style="height:90vh; overflow: hidden"
      append-to-body
    >
      <HxlhTable
        style="width: 100%"
        :columns="subGridOptions"
        :data="subList"
        :loading="loadingSub"
        :height="heightSub"
      >
      </HxlhTable>
      <template #footer>
        <span class="dialog-footer">
          <el-button @click="openDialog = false">{{
            $t("common.common.close")
          }}</el-button>
        </span>
      </template>
    </el-dialog>
    <el-dialog
      :title="$t('plan.btns.batchUpdateOrderDate')"
      v-model="openBatchDialog"
      width="85%"
      style="min-height:90vh; overflow: hidden"
      append-to-body
    >
      <div class="mode_box">
        <span>{{ $t("plan.title.setMode") }}</span>
        <el-radio-group v-model="radio" @change="changeRadioCustom">
          <el-radio :label="1">{{
            $t("plan.btns.batchUpdateOrderDate")
          }}</el-radio>
          <!-- <el-radio :label="2">{{
            $t("plan.title.CustomizePlannedCompletionDate")
          }}</el-radio> -->
        </el-radio-group>
      </div>
      <div class="red_color" v-if="radio === 1">{{ $t("plan.title.tipsBugSheetMetal") }}</div>
      <div class="red_color" v-if="radio === 2">{{ $t("plan.title.tipsBugSheetMetal2") }}</div>
      <div class="mode_box" v-if="radio === 2">
        <span>{{ $t("plan.title.CustomizePlannedCompletionDate") }}</span>
        <!-- <el-date-picker
          v-model="customicDate"
          type="dates"
          :placeholder="$t('plan.title.CustomizePlannedCompletionDate')"
          @change="handleChangeCustomDate($event)"
        /> -->
        <el-date-picker
          v-model="customicDate"
          type="datetime"
          :placeholder="$t('plan.title.CustomizePlannedCompletionDate')"
          @change="handleChangeCustomDate($event)"
        />
      </div>
      <HxlhTable
        v-if="radio === 1"
        style="width: 100%"
        :columns="subUpdateGridOptions"
        :data="subUpdateList"
        :loading="loading"
        :height="heightSubUpdate"
      >
      </HxlhTable>
      <HxlhTable
        v-if="radio === 2"
        style="width: 100%"
        :columns="subUpdateCustomGridOptions"
        :data="subUpdateList"
        :loading="loading"
        :height="heightSubUpdate"
      >
      </HxlhTable>
      <template #footer>
        <span class="dialog-footer">
          <el-button @click="openBatchDialog = false">{{
            $t("common.common.cancel")
          }}</el-button>
          <el-button
            type="primary"
            @click="hanleBatchUpdateDate"
            :disabled="loadingUpdateDate"
            v-hasPermi="['ApsPlatOrderPlanManager:requirement:list']"
            >{{ $t("common.common.batchUpdate") }}</el-button
          >
        </span>
      </template>
    </el-dialog>
    <!-- 查看上下阶 -->
    <el-dialog
      :title="$t('plan.title.viewUpperLowerLevels')"
      v-model="openUpperLowerDialog"
      width="85%"
      style="height:90vh; overflow: hidden"
      append-to-body
    >
      <HxlhTable
        style="width: 100%"
        :columns="subUpAndDownGridOptions"
        :data="subUpAndDownList"
        :loading="loadingSubUpAndDown"
        :height="heightSub"
      >
      </HxlhTable>
      <template #footer>
        <span class="dialog-footer">
          <el-button @click="openUpperLowerDialog = false">{{
            $t("common.common.close")
          }}</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="SheetMetalOrderManage">
import HxlhTable from "@/components/HxlhTable";
import { parseTime } from "@/utils/ruoyi.js";
import useBasicStore from "@/store/modules/request/basic/page";
import { listAll_plant } from "@/api/basicData/plant";
import {
  metalOrderManageList,
  metalOrderManageSubList,
  metalOrderManageUpAndDownList,
  generatorPlanList,
  planDateList,
} from "@/api/mainPlan/metalOrderManage.js";
import { useI18n } from "vue-i18n"; //要在js中使用国际化
import { ElMessage } from "element-plus";
const { t, locale } = useI18n();
const basicStore = useBasicStore();
const { proxy } = getCurrentInstance();
const { aps_work_order_type } = proxy.useDict("aps_work_order_type");
const { aps_factory   } = proxy.useDict("aps_factory");
const { aps_has_risk   } = proxy.useDict("aps_has_risk");
const delayRiskOptions = ref([]);
const radio = ref(1);
const customicDate = ref("");
const openDialog = ref(false);
const openUpperLowerDialog = ref(false);
const openBatchDialog = ref(false);
const subGridOptions = ref([]);
const subUpAndDownGridOptions = ref([]);
const subUpdateGridOptions = ref([]);
const subUpdateCustomGridOptions = ref([]);
const subUpAndDownList = ref([]);
const subList = ref([]);
const subUpdateList = ref([]);
// const tableRef = ref();
const orderList = ref([]);
const loading = ref(false);
const loadingUpdateDate = ref(false);
const loadingGenerateList = ref(false);
const loadingSubUpAndDown = ref(false);
const loadingSub = ref(false);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");
const data = reactive({
  form: {
    type: "1",
  },
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    workOrderNo: null,
    requireTrackId: null,
    mainPartNumber: null,
    hasDelayRisk: null,
  },
});
const { queryParams, form, rules } = toRefs(data);
const plantList = ref([]);
const shopList = ref([]);
const allShopList = ref([]);
const processList = ref([]);
const height = ref(document.documentElement.clientHeight - 220 + "px;");
const heightSub = ref(document.documentElement.clientHeight - 200 + "px;");
const heightSubUpdate = ref(document.documentElement.clientHeight - 270 + "px;");
// 表格配置-列表
const columns = ref([]);
// 分页属性
const page = ref({
  total: 0,
  current: 1,
  size: 10,
});
watch(
  locale,
  (newLocale) => {
    delayRiskOptions.value = [
      {
        label: t("plan.options.hasRisk"),
        value: "1",
      },
      {
        label: t("plan.options.noRisk"),
        value: "0",
      },
    ];
    columns.value = [
      { type: "checkbox", width: 60, align: "center", fixed: "left" },
      // {
      //   title: t("basic.table.requirementID"),
      //   field: "requireId",
      //   width: 150,
      //   align: "center",
      // },
      {
        title: t("basic.table.requirementTraceabilityID"),
        field: "requireTrackId",
        width: "auto",
        align: "center",
      },
      {
        title: t("plan.table.workOrderNo"),
        field: "workOrderNo",
        width: "auto",
        align: "center",
      },
      {
        title: t("basic.table.matchQuantity"),
        field: "deductionAmount",
        width: "auto",
        align: "center",
      },
      {
        title: t("basic.table.workOrderType"),
        field: "workOrderType",
        width: "auto",
        align: "center",
        formatter: ({ cellValue, row, column }) => {
          if (cellValue) {
            for (let i = 0; i < aps_work_order_type.value.length; i++) {
              if (cellValue === aps_work_order_type.value[i].value) {
                return aps_work_order_type.value[i].label;
              }
            }
          }
        },
      },
      {
        title: t("plan.table.itemNumber"),
        field: "mainPartNumber",
        width: "auto",
        align: "center",
      },
      {
        title: t("plan.table.mainPartDrawingNumber"),
        field: "mainPartDrawingNumber",
        width: "auto",
        align: "center",
      },
      {
        title: t("basic.table.mainCustomer"),
        field: "customer",
        width: "auto",
        align: "center",
      },
      {
        title: t("plan.table.productionQuantity"),
        field: "productionQuantity",
        width: "auto",
        align: "center",
      },
      {
        title: t("basic.table.applicableFactories"),
        field: "applicableFactories",
        width: 100,
        align: "center",
        formatter: ({ cellValue, row, column }) => {
          if (cellValue) {
            for (let i = 0; i < aps_factory.value.length; i++) {
              if (cellValue === aps_factory.value[i].value) {
                return aps_factory.value[i].label;
              }
            }
          }
        },
      },
      {
        title: t("plan.table.productionBase"),
        field: "productionBase",
        width: "auto",
        align: "center",
      },
      {
        title: t("plan.table.planStartDay"),
        field: "planStartDay",
        width: "auto",
        align: "center",
      },
      {
        title: t("plan.table.planEndDayDate"),
        field: "planEndDay",
        width: "auto",
        align: "center",
      },
      {
        title: t("plan.table.workorderCreationTime"),
        field: "orderCreateTime",
        width: "auto",
        align: "center",
      },
      {
        title: t("plan.table.mismatchedProductionQuantity"),
        field: "unmatchedQuantity",
        width: "auto",
        align: "center",
      },
      {
        title: t("plan.table.delayRiskIdentification"),
        field: "hasDelayRisk",
        width: 100,
        align: "center",
        formatter: ({ cellValue, row, column }) => {
          if (cellValue) {
            for (let i = 0; i < aps_has_risk.value.length; i++) {
              if (cellValue === aps_has_risk.value[i].value) {
                return aps_has_risk.value[i].label;
              }
            }
          }
        },
      },
      {
        title: t("common.common.require"),
        width: "auto",
        fixed: "right",
        slots: { default: "buttons" },
        align: "center",
      },
    ];
    subGridOptions.value = [
      {
        title: t("basic.table.requirementID"),
        field: "id",
        width: 150,
        align: "center",
      },
      // {
      //   title: t("basic.table.requirementTraceabilityID"),
      //   field: "requireId",
      //   width: 200,
      //   align: "center",
      // },
      {
        title: t("plan.table.itemNumber"),
        field: "bomLineCode",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.bomLowCode"),
        field: "bomLineLevel",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.bomUsage"),
        field: "bomUseAmount",
        width: 200,
        align: "center",
      },
      // {
      //   title: t("basic.table.processRouteID"),
      //   field: "processRouteId",
      //   width: 200,
      //   align: "center",
      // },
      // {
      //   title: t("plan.table.processRouteWorkingHours"),
      //   field: "processRouteHours",
      //   width: 100,
      //   align: "center",
      // },
      {
        title: t("plan.table.demandQuantity"),
        field: "requireAmount",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.netRequirement"),
        field: "netRequirement",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.planStartDay"),
        field: "startDate",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.planEndDayDate"),
        field: "completeDate",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.requirementDate"),
        field: "demandDate",
        width: 100,
        align: "center",
      },
      {
        title: t("basic.table.applicableFactories"),
        field: "orgCode",
        width: 100,
        align: "center",
        formatter: ({ cellValue, row, column }) => {
          if (cellValue) {
            for (let i = 0; i < aps_factory.value.length; i++) {
              if (cellValue === aps_factory.value[i].value) {
                return aps_factory.value[i].label;
              }
            }
          }
        },
      },
      {
        title: t("plan.table.productionBase"),
        field: "productionBase",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.matchState"),
        field: "matchState",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.matchPattern"),
        field: "matchMode",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.unmatchedDemandQuantity"),
        field: "unmatchedDemandAmount",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.suggestedCompletionDate"),
        field: "suggestedCompletionDate",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.delayRiskIdentification"),
        field: "hasDelayRisk",
        width: 100,
        align: "center",
        formatter: ({ cellValue, row, column }) => {
          if (cellValue) {
            for (let i = 0; i < aps_has_risk.value.length; i++) {
              if (cellValue === aps_has_risk.value[i].value) {
                return aps_has_risk.value[i].label;
              }
            }
          }
        },
      },
    ];
    subUpAndDownGridOptions.value = [
      {
        title: t("plan.table.documentNumber"),
        field: "documentNumber",
        align: "center",
      },
      {
        title: t("plan.table.level"),
        field: "requirementType",
        align: "center",
      },
      {
        title: t("plan.table.itemNumber"),
        field: "itemNumber",
        align: "center",
      },
      {
        title: t("plan.table.planStartDay"),
        field: "planStartDay",
        align: "center",
      },
      {
        title: t("plan.table.planEndDay"),
        field: "planEndDay",
        align: "center",
      },
      {
        title: t("plan.table.productionQuantity"),
        field: "productionQuantity",
        align: "center",
      },
    ]
    subUpdateGridOptions.value = [
      // {
      //   title: t("basic.table.requirementID"),
      //   field: "requireId",
      //   width: 150,
      //   align: "center",
      // },
      {
        title: t("basic.table.requirementTraceabilityID"),
        field: "requireTrackId",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.workOrderNo"),
        field: "workOrderNo",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.matchQuantity"),
        field: "deductionAmount",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.workOrderType"),
        field: "workOrderType",
        width: 200,
        align: "center",
        formatter: ({ cellValue, row, column }) => {
          if (cellValue) {
            for (let i = 0; i < aps_work_order_type.value.length; i++) {
              if (cellValue === aps_work_order_type.value[i].value) {
                return aps_work_order_type.value[i].label;
              }
            }
          }
        },
      },
      {
        title: t("plan.table.itemNumber"),
        field: "mainPartNumber",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.planStartDay"),
        field: "planStartDay",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.planEndDayDate"),
        field: "planEndDay",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.startDateOfDemandPlan"),
        field: "startDate",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.requirementPlanCompletionDate"),
        field: "completeDate",
        width: 200,
        align: "center",
      },
    ];
    subUpdateCustomGridOptions.value = [
      // {
      //   title: t("basic.table.requirementID"),
      //   field: "requireId",
      //   width: 150,
      //   align: "center",
      // },
      {
        title: t("basic.table.requirementTraceabilityID"),
        field: "requireTrackId",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.workOrderNo"),
        field: "workOrderNo",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.matchQuantity"),
        field: "deductionAmount",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.workOrderType"),
        field: "workOrderType",
        width: 200,
        align: "center",
        formatter: ({ cellValue, row, column }) => {
          if (cellValue) {
            for (let i = 0; i < aps_work_order_type.value.length; i++) {
              if (cellValue === aps_work_order_type.value[i].value) {
                return aps_work_order_type.value[i].label;
              }
            }
          }
        },
      },
      {
        title: t("plan.table.itemNumber"),
        field: "mainPartNumber",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.planStartDay"),
        field: "planStartDay",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.planEndDayDate"),
        field: "planEndDay",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.customizePlannedCompletionDate"),
        field: "customTime",
        width: 200,
        align: "center",
      },
    ];
  },
  {
    immediate: true,
    deep: true,
  }
);
function changeRadioCustom() {}
function handleBatchUpdatePlanDate() {
  openBatchDialog.value = true;
}
function handleChangeCustomDate(e) {
  customicDate.value = parseTime(e); //new Date(e).getFullYear()+ '-' + parseInt(new Date(e).getMonth()*1+1) + '-' +  new Date(e).getDate()
  console.log(customicDate.value, "chang date");
  if (radio.value == 2) {
    subUpdateList.value = subUpdateList.value.map((item) => {
      return {
        ...item,
        customTime: customicDate.value,
      };
    });
    console.log(subUpdateList.value, "changeRadioCustom");
  }
}
function handleCheckView(row) {
  openDialog.value = true;
  loadingSub.value = true;
  metalOrderManageSubList(row.workOrderNo)
    .then((res) => {
      subList.value = res;
      loadingSub.value = false;
    })
    .catch(() => {
      loadingSub.value = false;
    });
}
function handleCheckLevels(row) {
  openUpperLowerDialog.value = true;
  loadingSubUpAndDown.value = true;
  metalOrderManageUpAndDownList({requireId: row.requireId}).then((res) => {
    console.log(res,"metalOrderManageUpAndDownList");
    subUpAndDownList.value = res.rows;
    loadingSubUpAndDown.value = false;
  }).catch(() => {
    loadingSubUpAndDown.value = false;
  });
}
async function hanleBatchUpdateDate() {
  loadingUpdateDate.value = true;
  let planIds = subUpdateList.value.map((item) => {
    return item.id;
  });
  let res = null;
  console.log(planIds, "planIds");
  if (radio.value == 1) {
    res = await planDateList({
      isCustom: false,
      planIds,
    });
  } else {
    res = await planDateList({
      isCustom: true,
      planIds,
      customDate: customicDate.value,
    });
    console.log(res, "res planDateList");
  }
  if (res.code === 200) {
    ElMessage({
      message: t("plan.message.update"),
      type: "success",
    });
    openBatchDialog.value = false;
    loadingUpdateDate.value = false;
    getList();
  } else {
    openBatchDialog.value = true;
    loadingUpdateDate.value = false;
  }
}
async function handleGenerateList() {
  loadingGenerateList.value = true;
  const res = await generatorPlanList();
  if (res.code == 200) {
    ElMessage({
      message: t("plan.message.update"),
      type: "success",
    });
    loadingGenerateList.value = false;
    getList();
  } else {
    loadingGenerateList.value = false;
  }
}
/** 查询钣金工单计划管理列表 */
function getList() {
  loading.value = true;
  metalOrderManageList(queryParams.value)
    .then((response) => {
      orderList.value = response.rows;
      page.value.total = response.total;
      loading.value = false;
    })
    .catch((res) => {
      loading.value = false;
    });
}

// axios
//   .all([
//     /** 查询工厂列表 */
//     listAll_plant({}),
//     /** 查询车间列表 */
//     listAll_shop({}),
//   ])
//   .then(
//     axios.spread((response1, response2) => {
//       plantList.value = response1.data;
//       shopList.value = response2.data;
//       loading.value = false;
//     })
//   )
//   .catch((error) => {
//     console.error("请求出错:", error);
//   });
/** 搜索按钮操作 */
function handleQuery() {
  console.log("111111");
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}
function changePageNo(currentPage) {
  queryParams.value.pageNum = currentPage;
  page.value.current = currentPage;
  getList();
}
function changePageSize(pageSize) {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  queryParams.value.pageSize = pageSize;
  getList();
}
// 多选框选中数据
const handleCheckboxChange = (data) => {
  console.log(data, "handleCheckboxChange");
  ids.value = data.records.map((item) => item.id);
  single.value = data.records.length !== 1;
  multiple.value = !data.records.length;
  subUpdateList.value = data.records;
};
onMounted(() => {
  getList();
});
</script>
<style lang="scss" scoped>
.column-with-margin {
  margin-right: 0px;
}
.mode_box {
  margin-left: 30px;
  margin-bottom: 10px;
  & span {
    padding-right: 20px;
  }
}
.red_color {
  color: #f56c6c;
  margin-bottom: 10px;
}
.mart5 {
  margin-top: 5px;
}
</style>
